@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2013, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package registry
@@ -36,6 +36,7 @@ type Bucket struct {
 	Destination                              string
 	BucketLabels                             map[string]string
 	BuildLabels                              map[string]string
+	Channels                                 []string
 	SourceExternalIdentifierToParentVersions map[string]ParentVersion
 	RunningBuilds                            map[string]chan struct{}
 	Version                                  *Version
@@ -94,6 +95,7 @@ func (bucket *Bucket) ReadFromHCPPackerRegistryBlock(registryBlock *hcl2template
 	bucket.Description = registryBlock.Description
 	bucket.BucketLabels = registryBlock.BucketLabels
 	bucket.BuildLabels = registryBlock.BuildLabels
+	bucket.Channels = registryBlock.Channels
 	// If there's already a Name this was set from env variable.
 	// In Packer, env variable overrides config values so we keep it that way for consistency.
 	if bucket.Name == "" && registryBlock.Slug != "" {
@@ -244,6 +246,28 @@ func (bucket *Bucket) uploadSbom(ctx context.Context, buildName string, sbom pac
 	return bucket.client.UploadSbom(ctx, bucket.Name, bucket.Version.Fingerprint, buildToUpdate.ID, sbom)
 }
 
+func (bucket *Bucket) updateChannels(ctx context.Context, ui packerSDK.Ui) error {
+	if len(bucket.Channels) == 0 {
+		return nil
+	}
+
+	body := &hcpPackerModels.HashicorpCloudPacker20230101UpdateChannelBody{
+		VersionFingerprint: bucket.Version.Fingerprint,
+		UpdateMask:         "versionFingerprint",
+	}
+
+	for _, channel := range bucket.Channels {
+		ui.Say(fmt.Sprintf("==> Assigning version `%s` to channel `%s`", bucket.Version.Fingerprint, channel))
+		_, err := bucket.client.UpdateChannel(ctx, bucket.Name, channel, body)
+		if err != nil {
+			ui.Error(fmt.Sprintf("==> Failed assigning version `%s` to channel `%s`: %v", bucket.Version.Fingerprint, channel, err))
+			return fmt.Errorf("failed to update channel %s: %w", channel, err)
+		}
+	}
+
+	return nil
+}
+
 // markBuildComplete should be called to set a build on the HCP Packer registry to DONE.
 // Upon a successful call markBuildComplete will publish all artifacts created by the named build,
 // and set the build to done. A build with no artifacts can not be set to DONE.
@@ -627,6 +651,7 @@ func (bucket *Bucket) completeBuild(
 	ctx context.Context,
 	buildName string,
 	packerSDKArtifacts []packerSDK.Artifact,
+	ui packerSDK.Ui,
 	buildErr error,
 ) ([]packerSDK.Artifact, error) {
 	doneCh, ok := bucket.RunningBuilds[buildName]
@@ -651,7 +676,7 @@ func (bucket *Bucket) completeBuild(
 		return packerSDKArtifacts, fmt.Errorf("build failed, not uploading artifacts")
 	}
 
-	artifacts, err := bucket.doCompleteBuild(ctx, buildName, packerSDKArtifacts, buildErr)
+	artifacts, err := bucket.doCompleteBuild(ctx, buildName, packerSDKArtifacts, ui, buildErr)
 	if err != nil {
 		err := bucket.UpdateBuildStatus(ctx, buildName, hcpPackerModels.HashicorpCloudPacker20230101BuildStatusBUILDFAILED)
 		if err != nil {
@@ -666,6 +691,7 @@ func (bucket *Bucket) doCompleteBuild(
 	ctx context.Context,
 	buildName string,
 	packerSDKArtifacts []packerSDK.Artifact,
+	ui packerSDK.Ui,
 	buildErr error,
 ) ([]packerSDK.Artifact, error) {
 	for _, art := range packerSDKArtifacts {
@@ -726,6 +752,12 @@ func (bucket *Bucket) doCompleteBuild(
 			parErr)
 	}
 
+	// Update channels after build is marked complete
+	channelErr := bucket.updateChannels(ctx, ui)
+	if channelErr != nil {
+		log.Printf("[ERROR] Failed to update channels after completing build %s: %s", buildName, channelErr)
+	}
+
 	return append(packerSDKArtifacts, &registryArtifact{
 		BuildName:  buildName,
 		BucketName: bucket.Name,
