@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2013, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package packer
@@ -24,7 +24,7 @@ type BuildGetter interface {
 	// GetBuilds return all possible builds for a config. It also starts all
 	// builders.
 	// TODO(azr): rename to builder starter ?
-	GetBuilds(GetBuildsOptions) ([]packersdk.Build, hcl.Diagnostics)
+	GetBuilds(GetBuildsOptions) ([]*CoreBuild, hcl.Diagnostics)
 }
 
 type Evaluator interface {
